summaryrefslogtreecommitdiff
path: root/Lib/test/pythoninfo.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/test/pythoninfo.py')
-rw-r--r--Lib/test/pythoninfo.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/test/pythoninfo.py b/Lib/test/pythoninfo.py
index c238ef7b75..85e32a9ae7 100644
--- a/Lib/test/pythoninfo.py
+++ b/Lib/test/pythoninfo.py
@@ -1,5 +1,5 @@
"""
-Collect various informations about Python to help debugging test failures.
+Collect various information about Python to help debugging test failures.
"""
from __future__ import print_function
import errno
@@ -40,7 +40,7 @@ class PythonInfo:
def get_infos(self):
"""
Get informations as a key:value dictionary where values are strings.
"""
return {key: str(value) for key, value in self.info.items()}
@@ -40,7 +40,7 @@ class PythonInfo:
def get_infos(self):
"""
- Get informations as a key:value dictionary where values are strings.
+ Get information as a key:value dictionary where values are strings.
"""
return {key: str(value) for key, value in self.info.items()}